%bcond_with bootstrap

Name:           xbean
Version:        4.18
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java plugin based web server
License:        ASL 2.0
URL:            https://geronimo.apache.org/xbean/
BuildArch:      noarch

Source0:        https://repo1.maven.org/maven2/org/apache/%{name}/%{name}/%{version}/%{name}-%{version}-source-release.zip

Patch1:         0001-Remove-unused-import.patch
Patch2:         0002-Unbundle-ASM.patch
Patch3:         0003-Remove-dependency-on-log4j-and-commons-logging.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.osgi:org.osgi.core)
BuildRequires:  mvn(org.ow2.asm:asm)
BuildRequires:  mvn(org.ow2.asm:asm-commons)
BuildRequires:  mvn(org.slf4j:slf4j-api)
%endif

%description
The goal of XBean project is to create a plugin based server
analogous to Eclipse being a plugin based IDE. XBean will be able to
discover, download and install server plugins from an Internet based
repository. In addition, we include support for multiple IoC systems,
support for running with no IoC system, JMX without JMX code,
lifecycle and class loader management, and a rock solid Spring
integration.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package provides %{summary}.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1

cp xbean-asm-util/src/main/java/org/apache/xbean/asm9/original/commons/AsmConstants.java xbean-reflect/src/main/java/org/apache/xbean/recipe/

# Parent POM is not packaged
%pom_remove_parent

%pom_disable_module xbean-classloader
%pom_disable_module xbean-classpath
%pom_disable_module xbean-bundleutils
%pom_disable_module xbean-asm9-shaded
%pom_disable_module xbean-finder-shaded
%pom_disable_module xbean-naming
%pom_disable_module xbean-blueprint
%pom_disable_module xbean-spring
%pom_disable_module xbean-telnet
%pom_disable_module maven-xbean-plugin

%pom_remove_dep :commons-logging-api xbean-reflect
%pom_remove_dep :log4j xbean-reflect
%pom_remove_dep :xbean-asm9-shaded xbean-reflect
find -name CommonsLoggingConverter.java -delete
find -name Log4jConverter.java -delete

# Plugins useful for upstream only
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :maven-source-plugin

%pom_remove_dep :xbean-bundleutils xbean-finder
rm -r xbean-finder/src/main/java/org/apache/xbean/finder{,/archive}/Bundle*

# Disable one test that fails on JDK 11
sed -i '/testGetBytecode/i@org.junit.Ignore' xbean-finder/src/test/java/org/apache/xbean/finder/archive/MJarJarArchiveTest.java

%build
%mvn_build -- -Dmaven.compiler.source=1.7 -Dmaven.compiler.target=1.7

%install
%mvn_install

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE


%changelog
* Mon Jul 25 2022 neoclust <neoclust> 4.18-2.mga9
+ Revision: 1871444
- Disable bootstrap

* Mon Jul 25 2022 neoclust <neoclust> 4.18-1.mga9
+ Revision: 1870969
- New version 4.18
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Dec 28 2020 neoclust <neoclust> 4.15-2.mga8
+ Revision: 1664423
- Switch from log4j 1.2 compat package to log4j 1.2 API shim.

* Sun Sep 06 2020 daviddavid <daviddavid> 4.15-1.mga8
+ Revision: 1622855
- Update to version 4.15
- Fix JVM as 1.8.0 as package cannot be built with Java 9 and above
- Remove springframework conditionals, the deps are a long time removed from
  Fedora and this simplifies the spec a bit
- Disable unused modules that can't build on JDK 11

* Sun Feb 16 2020 umeabot <umeabot> 4.14-2.mga8
+ Revision: 1536137
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 4.14-1.mga8
+ Revision: 1453318
- Update to version 4.14
- Migrate from the obsolete felix-osgi-core to osgi-core

* Thu Aug 01 2019 daviddavid <daviddavid> 4.9-3.mga8
+ Revision: 1426775
- Disable support for spring and groovy

* Fri Jul 19 2019 daviddavid <daviddavid> 4.9-2.mga8
+ Revision: 1422812
- Disable eclipse equinox functionality to fix the FTBFS issue on 32bit arches

* Mon Dec 31 2018 daviddavid <daviddavid> 4.9-1.mga7
+ Revision: 1347520
- new version: 4.9 (sync with fc29)

* Wed Sep 19 2018 umeabot <umeabot> 4.5-2.mga7
+ Revision: 1277194
- Mageia 7 Mass Rebuild

* Fri May 19 2017 neoclust <neoclust> 4.5-1.mga6
+ Revision: 1103414
- New version 4.5
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 4.4-2.mga6
+ Revision: 978221
- First rebuild of the java stack
- sync package xbean with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Feb 20 2015 daviddavid <daviddavid> 3.17-5.mga5
+ Revision: 816122
- rebuild for new jruby, yecht and nailgun
- add missing BuildRequires on options and jffi-native

* Fri Jan 30 2015 daviddavid <daviddavid> 3.17-4.mga5
+ Revision: 812719
- add missing BuildRequires on jboss-el-2.2-api
- add missing BuildRequires on jboss-servlet-3.0-api
- fix Group

* Sat Dec 27 2014 pterjan <pterjan> 3.17-3.mga5
+ Revision: 806417
- Clean rebuild
- Rebuild with spring
- Sync with Fedora 21 (update to 3.17)
+ luigiwalser <luigiwalser>
- build without spring
+ sander85 <sander85>
- Well, try to drop xbean-spring as well as it depends on springframework-web which will be dropped
- Try to drop maven-xbean-plugin as it depends on dropped xbean-spring

* Wed Oct 15 2014 umeabot <umeabot> 3.16-5.mga5
+ Revision: 741613
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ dmorgan <dmorgan>
- Disable P0: Try to fix clash

* Tue Dec 31 2013 dmorgan <dmorgan> 3.16-2.mga4
+ Revision: 563672
- Rebuild against fixed springframework

* Mon Dec 30 2013 dmorgan <dmorgan> 3.16-1.mga4
+ Revision: 563317
- New version

* Fri Dec 13 2013 dmorgan <dmorgan> 3.13-1.mga4
+ Revision: 556564
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 3.11.1-2.mga3
+ Revision: 386568
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dmorgan <dmorgan> 3.11.1-1.mga3
+ Revision: 293153
- New version

* Thu Sep 22 2011 gil <gil> 3.7-9.mga2
+ Revision: 146742
- rebuilt with spring2 support (added new modules: classloader spring maven-xbean-plugin)

* Wed Jul 20 2011 dmorgan <dmorgan> 3.7-8.mga2
+ Revision: 127124
- Remove unused hack
+ gil <gil>
- add patch1
- add patch1

* Thu Apr 28 2011 dmorgan <dmorgan> 3.7-7.mga1
+ Revision: 93151
- Rebuild after bootstrapping
- imported package xbean


* Fri Mar  4 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-6
- Add comment for removing javadoc
- Fix maven 3 build

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec  6 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-4
- Fix pom filename (Resolves rhbz#655827)
- Add depmap for main pom file
- Fixes according to new guidelines (versionless jars, javadocs)

* Fri Jul 30 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-3
- Use javadoc:aggregate to generate javadocs

* Fri Jul  9 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-2
- Add license to javadoc subpackage

* Mon Jun 21 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-1
- First release

